define(["dojo/_base/declare",
        "dojo/_base/lang",
        "dijit/_Widget",
        "dijit/_TemplatedMixin",
        "dijit/_WidgetsInTemplateMixin",
        "dojo/text!./templates/EditEmailDialog.html",
        "dojo/i18n!../nls/user_resources",
        "dojo/aspect",
        "dijit/Dialog",
        "dijit/form/Button",
        "admin/users/dialogs/ImportUserWizardController",
        "dojo/request/xhr",
        "dojox/validate/web",
        "dijit/layout/BorderContainer",
        "dijit/layout/ContentPane"
        ],
        function(dDeclare,
                dLang,
                dWidget,
                dTemplatedMixin,
                dWidgetsInTemplateMixin,
                templateText,
                resources,
                dAspect,
                Dialog,
                Button,
                ImportUserWizardController,
                xhr
                ) {
return dDeclare("admin.users.dialogs.EditEmailDialog", [dWidget,dTemplatedMixin,dWidgetsInTemplateMixin], 
{
    /**
     * @private
     */
    baseClass: "EditEmailDialog",

    /**
     * The widget template for the dijit._TemplatedMixin base class.
     */
    templateString: templateText,
      
    /** 
     * Indicate if this widget is also a container
     * @private
     */
    isContainer: false,
      
    /**
     * Indicate if there are widgets in the template
     */
    widgetsInTemplate: true,
      
    /**
     * Ok button label
     */
    okButtonLabel: resources['okButtonLabel'],
      
    /**
     * Cancel button label
     */
    cancelButtonLabel: resources['cancelButtonLabel'],
    /**
     * Email label
     */
    emailLabel: resources['emailAddressLabel'],
    /**
     * Dialog title
     */
    editEmailTitle: resources['editEmailTitle'],
    /**
     * Invalid email message
     */
    invalidEmailAddress: resources['invalidEmailAddress'],
    
    /**
     * The user whose email is being updated
     */
    selectedUser: null,
      
    /**
     * The resize function
     */
    resize: function() {
        this.inherited(arguments);
    },
      
    /**
     * The startup function
     */
    startup: function() {
        this.inherited(arguments);
        this.okButton.on("click", dLang.hitch(this, "_submitUpdate"));
        this.cancelButton.on("click", dLang.hitch(this, "_onCancelClick"));
        if (this.selectedUser != null) {
        	this.emailNode.set("value", this.selectedUser.userEmail);
        }
        this.emailNode.isValid = dLang.hitch(this,"isEmailValid");
        this.emailNode.on("change", dLang.hitch(this, "_validate"));
        this.dialog.show();
    },
    
    /**
     * Validates the email address and enables/disables the okay button accordingly
     */
     _validate:function() {
    	 var valid = false;
    	 if (this.emailNode.isValid() && this.emailNode.get("value") != "") {
    		if (this.emailNode.get("value") == this.selectedUser.userEmail) {
    			valid = false;
    		}
    		else {
    			valid = true;
    		}
    	 }
    	 this.okButton.set("disabled", !valid);
    	 
     },
     
     /**
      * Check if the current email is valid
      */
     isEmailValid:function() {
    	 var email = this.emailNode.get("value");
    	 return dojox.validate.isEmailAddress(email);
     },
      
      /**
       * The postCreate function
       */
      postCreate: function () {
          this.inherited(arguments);
      },
      
      /**
       * The destroy function
       */
      destroy: function() {
    	  this.inherited(arguments);
          //this.dialog.destroyRecursive();
          
      },
      
    /**
     * The OK button handler
     */
    _submitUpdate:function() {
    	this.selectedUser.userEmail = this.emailNode.get("value");
    	var user = {"identifier":"userId","label":"name","items":[{userId: this.selectedUser.userId[0], userName: this.selectedUser.userName[0], userEmail: this.selectedUser.userEmail}]};
    	console.log(user);
		xhr.put("/optim/rest/security/user/"+this.selectedUser.userId, 
        {
        	handleAs: "text",
        	data: JSON.stringify(user),
        	sync: true
        }).then(function(data){
            // Do nothing - no data is returned
        	console.log(data);
        }, function(err){
            //TODO display error message (should be in dita format)
        	console.log(err);
        }, function(evt){
        	//do nothing
        	console.log(evt);
        });
		this.onComplete();
        this.dialog.destroyRecursive();
        this.destroyRecursive();
          
    },
    
    /**
     * Get the email address
     */
    getEmailAddress:function() {
    	return this.emailNode.get("value");
    },
    
    /**
     * Place holder for onComplete
     */
    onComplete:function() {
    	
    },
     
    /**
     * The cancel button handler
     */
    _onCancelClick:function() {
        this.dialog.destroyRecursive();
        this.destroyRecursive();
    }
});
});
